slepc-3.18.0 2022-10-01
Report Typos and Errors

# MFNConvergedReasonView

Displays the reason an MFN solve converged or diverged.

### Synopsis

    #include "slepcmfn.h"
    PetscErrorCode MFNConvergedReasonView(MFN mfn,PetscViewer viewer)

Collective on mfn

### Input Parameters

| mfn | - the matrix function context
| viewer | - the viewer to display the reason

### Options Database Keys

| -mfn_converged_reason | - print reason for convergence, and number of iterations

### Note

To change the format of the output call PetscViewerPushFormat(viewer,format) before this call. Use PETSC_VIEWER_DEFAULT for the default, use PETSC_VIEWER_FAILED to only display a reason if it fails. The latter can be set in the command line with -mfn_converged_reason ::failed

### See Also

MFNSetTolerances(), MFNGetIterationNumber(), MFNConvergedReasonViewFromOptions()

### Level

intermediate

### Location

src/mfn/interface/mfnbasic.c
Index of all MFN routines
Table of Contents for all manual pages
Index of all manual pages